begin

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$ Define positive direction for current flow
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

convention positive_current_flow=inward

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$   Load structure and map materials
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

load_mesh mesh_inf=IGBT.aps  suprem_import=yes
output sol_outf=IdVd_family.out

suprem_to_apsys_material suprem_mater=3 apsys_mater=1
suprem_to_apsys_material suprem_mater=1 apsys_mater=2
suprem_to_apsys_material suprem_mater=4 apsys_mater=3
suprem_to_apsys_material suprem_mater=2 apsys_mater=4
suprem_to_apsys_material suprem_mater=6 apsys_mater=5

suprem_property user_material_mapping = yes

load_macro name= si mater= 1
load_macro name= sio2 mater= 2
load_macro name= poly mater= 3
load_macro name=sin mater=4
load_macro name=al mater=5

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$ Define temperature
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

temperature temp=300

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$   Define contacts
$   Emitter=1
$   Gate=2
$   Collector=3
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

suprem_contact num=1 xrange=(0.0 10)  yrange=(-9999.000000 &&
9999.000000) touch_mater=5 side=upper

suprem_contact num=2 xrange=(3.4 10.0)  yrange=(0.1  &&
0.5) touch_mater=3 side=within

suprem_contact num=3 xrange=(0.0 10)  yrange=(-9999.000000 &&
9999.000000) touch_mater=1 side=lower

contact  num=1
contact  num=2
contact  num=3

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Define fixed oxide charge
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

$interface model=charge within_y=(-0.1, 0.1) within_x=(0, 9) &&
$ fix_charge=5e14

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Set carrier lifetime
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$


lifetime_n value=100e-9 mater=1
lifetime_p value=100e-9 mater=1


$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Specify Lombardi Mobility and Chynoweth Impact Ionization Models
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

mobility_xy elec_field_model=lombardi hole_field_model=lombardi

impact_chynoweth mater=1
impact_chynoweth mater=2
impact_chynoweth mater=3
impact_chynoweth mater=4


$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Scale the active areas--Die size =0.1 cm^2
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

3d_solution_method skip_fv_data=yes
z_structure single_plane_zdim=8.33E5

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Specify output data and numerical parameters
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

more_output space_charge=yes impact_ionization=yes ac_data=no &&
 elec_mobility=yes hole_mobility=yes


newton_par damping_step=8. var_tol=1.e-1 res_tol=1.e-1 &&
  max_iter=25 opt_iter=15 stop_iter=1


equilibrium outfile_label=vg0




$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Scan collector voltage to 0.1V
$  Then scan gate to Vg=10
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

$ Ic-Vd @ Vg=0
scan var=voltage_3 value_to=10 &&
  init_step=1e-3 min_step=1e-9 max_step=1

start_loop symbol=%outf value_from=1 value_to=5
loop_integer symbol=%inf value_from=0 value_to=4
loop_real symbol=%gate_bias value_from=7 value_to=15

$ Update gate voltage and reset drain as part of infile_label loading
scan var=voltage_2 value_to=%gate_bias &&
  init_step=1e-3 min_step=1e-9 max_step=0.5 &&
  infile_label=vg%inf outfile_label=vg%outf

$ Ic-Vd @ Vg
scan var=voltage_3 value_to=10 &&
  init_step=1e-3 min_step=1e-9 max_step=1

end_loop


end